@@ -68,6 +68,30 @@ pub enum Subcommands {
         /// It's a form of instrumentation for developers to help improve pack generation.
         statistics: bool,
 
+        #[clap(long)]
+        /// The size in megabytes for a cache to speed up pack access for packs with long delta chains.
+        /// It is shared among all threads, so 4 threads would use their own cache 1/4th of the size.
+        ///
+        /// If unset, no cache will be used.
+        pack_cache_size_mb: Option<usize>,
+
+        #[clap(long)]
+        /// The size in megabytes for a cache to speed up accessing entire objects, bypassing object database access when hit.
+        /// It is shared among all threads, so 4 threads would use their own cache 1/4th of the size.
+        ///
+        /// This cache type is currently only effective when using the 'diff-tree' object expansion.
+        ///
+        /// If unset, no cache will be used.
+        object_cache_size_mb: Option<usize>,
+
+        #[clap(long)]
+        /// if set, delta-objects whose base object wouldn't be in the pack will not be recompressed as base object, but instead
+        /// refer to its base object using its object id.
+        ///
+        /// This allows for smaller packs but requires the receiver of the pack to resolve these ids before storing the pack.
+        /// Packs produced with this option enabled are only valid in transit, but not at rest.
+        thin: bool,
+
         /// The directory into which to write the pack file.
         #[clap(long, short = 'o')]
         output_directory: Option<PathBuf>,
@@ -90,7 +114,7 @@ pub enum Subcommands {
         /// the directory into which to write references. Existing files will be overwritten.
         ///
         /// Note that the directory will be created if needed.
-        #[clap(long, short = 'r')]
+        #[clap(long, short = 'd')]
         refs_directory: Option<PathBuf>,
 
         /// The URLs or path from which to receive the pack.
@@ -98,6 +122,12 @@ pub enum Subcommands {
         /// See here for a list of supported URLs: <https://www.git-scm.com/docs/git-clone#_git_urls>
         url: String,
 
+        /// If set once or more times, these references will be fetched instead of all advertised ones.
+        ///
+        /// Note that this requires a reasonably modern git server.
+        #[clap(long = "reference", short = 'r')]
+        refs: Vec<String>,
+
         /// The directory into which to write the received pack and index.
         ///
         /// If unset, they will be discarded.
